@@ -18,16 +18,29 @@ if 'BANANA_URL' in os.environ:
 # ___________________________________
 
 
-def run_main(api_key, model_key, model_inputs, strategy):
-    call_id = start_api(api_key, model_key, model_inputs, strategy)
+def run_main(api_key, model_key, model_inputs):
+    result = start_api(api_key, model_key, model_inputs)
+
+    # likely we get results on first call
+    if result["finished"]:
+        dict_out = {
+            "id": result["id"],
+            "message": result["message"],
+            "created": result["created"],
+            "apiVersion": result["apiVersion"],
+            "modelOutputs": result["modelOutputs"]
+        }
+        return dict_out
+
+    # else it's long running, so poll for result
     while True:
-        dict_out = check_api(api_key, call_id)
+        dict_out = check_api(api_key, result["callID"])
         if dict_out['message'].lower() == "success":
             return dict_out
 
-def start_main(api_key, model_key, model_inputs, strategy):
-    call_id = start_api(api_key, model_key, model_inputs, strategy)
-    return call_id
+def start_main(api_key, model_key, model_inputs):
+    result = start_api(api_key, model_key, model_inputs, start_only=True)
+    return result["callID"]
 
 def check_main(api_key, call_id):
     dict_out = check_api(api_key, call_id)
@@ -37,19 +50,19 @@ def check_main(api_key, call_id):
 # THE API CALLING FUNCTIONS
 # ________________________
 
-# Takes in start params, returns call ID
-def start_api(api_key, model_key, model_inputs, strategy):
+# Takes in start params and returns the full server json response
+def start_api(api_key, model_key, model_inputs, start_only=False):
     global endpoint
-    route_start = "start/v2/"
+    route_start = "start/v3/"
     url_start = endpoint + route_start
 
     payload = {
         "id": str(uuid4()),
-        "created": time.time(),
+        "created": int(time.time()),
         "apiKey" : api_key,
         "modelKey" : model_key,
         "modelInputs" : model_inputs,
-        "strategy": strategy,
+        "startOnly": start_only
     }
 
     response = requests.post(url_start, json=payload)
@@ -62,18 +75,15 @@ def start_api(api_key, model_key, model_inputs, strategy):
     except:
         raise Exception("server error: returned invalid json")
 
-    try:
-        if "error" in out['message'].lower():
-            raise Exception(out['message'])
-        call_id = out['callID']
-        return call_id
-    except:
-        raise Exception("server error: Failed to return call_id")
+    if "error" in out['message'].lower():
+        raise Exception(out['message'])
 
-# The bare async checker.
+    return out
+
+# Takes in call_id to return the server response
 def check_api(api_key, call_id):
     global endpoint
-    route_check = "check/v2/"
+    route_check = "check/v3/"
     url_check = endpoint + route_check
     # Poll server for completed task
 
